==> GNUMail-1.0.3.tar.gz: GNUMail/MessageViewWindowToolbar.h <==
/*
**  MessageViewWindowToolbar.h
**
**  Copyright (c) 2002
**
**  Author: Francis Lachapelle <francis@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#import "MessageViewWindowController.h"
#import "MailWindowController.h"

#import <Cocoa/Cocoa.h>


@interface MessageViewWindowController (MessageViewWindowToolbar)

     
//
// NSToolbar delegate methods
//

- (NSToolbarItem *) toolbar: (NSToolbar *) toolbar
      itemForItemIdentifier: (NSString *) itemIdentifier
  willBeInsertedIntoToolbar: (BOOL) flag;

- (NSArray *) toolbarAllowedItemIdentifiers: (NSToolbar*) toolbar;

- (NSArray *) toolbarDefaultItemIdentifiers: (NSToolbar*) toolbar;

//
// NSToolbarItemValidation protocol
//

- (BOOL) validateToolbarItem: (NSToolbarItem *) theItem;

@end



//
// NSToolbarItem subclass for navigation view
//

@interface NavigationToolbarItem: NSToolbarItem

{
  id delegate;
}

- (void) setDelegate: (id) theDelegate;

- (void) validate;

@end

==> GNUMail-1.2.0pre1.tar.gz: GNUMail/MessageViewWindowToolbar.h <==
/*
**  MessageViewWindowToolbar.h
**
**  Copyright (c) 2002-2004
**
**  Author: Francis Lachapelle <francis@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _GNUMail_H_MessageViewWindowToolbar
#define _GNUMail_H_MessageViewWindowToolbar

#import <AppKit/AppKit.h>

#include "MessageViewWindowController.h"

@interface MessageViewWindowController (MessageViewWindowToolbar)
     
//
// NSToolbar delegate methods
//
- (NSToolbarItem *) toolbar: (NSToolbar *) toolbar
      itemForItemIdentifier: (NSString *) itemIdentifier
  willBeInsertedIntoToolbar: (BOOL) flag;

- (NSArray *) toolbarAllowedItemIdentifiers: (NSToolbar*) toolbar;

- (NSArray *) toolbarDefaultItemIdentifiers: (NSToolbar*) toolbar;


//
// NSToolbarItemValidation protocol
//
- (BOOL) validateToolbarItem: (NSToolbarItem *) theItem;

@end

#endif // _GNUMail_H_MessageViewWindowToolbar
